@@ -1,24 +1,22 @@
-/***************************************************************************
-			disc.cpp
-
- *   Copyright (C) 2006 by Christophe Thommeret                                   *
- *   hftom@free.fr                                                         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
- ***************************************************************************/
+/*
+ * disc.cpp
+ *
+ * Copyright (C) 2006 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <qstringlist.h>
 #include <qlayout.h>
@@ -44,12 +42,11 @@
 #include "disc.h"
 #include "disc.moc"
 
-
-
 MLabel::MLabel( QWidget *parent ) : QLabel( parent )
 {
 	setText("<center><font size=\"6\"><b>"+i18n("Audio CD")+"</b></font></center>");
 }
+
 void MLabel::paintEvent( QPaintEvent *pe )
 {
 	QLabel::paintEvent( pe );
@@ -62,14 +59,10 @@ void MLabel::paintEvent( QPaintEvent *pe )
 	setPaletteBackgroundColor( QColor(r, g, b) );
 }
 
-
-
 MListView::MListView( QWidget *parent ) : KListView( parent )
 {
 }
 
-
-
 void MListView::resizeEvent( QResizeEvent *rev )
 {
 	int width = contentsRect().width();
@@ -80,8 +73,6 @@ void MListView::resizeEvent( QResizeEvent *rev )
 	KListView::resizeEvent(rev);
 }
 
-
-
 Disc::Disc( QWidget* parent, QObject *objParent, const char *name ) : KaffeineInput(objParent , name)
 {
 	mainWidget = new QVBox( parent );
@@ -196,13 +187,17 @@ Disc::Disc( QWidget* parent, QObject *objParent, const char *name ) : KaffeineIn
 	currentPixmap = UserIcon("playing");
 }
 
-
-
 Disc::~Disc()
 {
 }
 
-
+void Disc::togglePanel()
+{
+	if ( panel->isHidden() )
+		panel->show();
+	else
+		panel->hide();
+}
 
 void Disc::getTargets( QStringList &uiNames, QStringList &iconNames, QStringList &targetNames )
 {
@@ -220,8 +215,6 @@ void Disc::getTargets( QStringList &uiNames, QStringList &iconNames, QStringList
 	targetNames.append( "DISC_VCD" );
 }
 
-
-
 bool Disc::execTarget( const QString &target )
 {
 	if ( target=="DISC_CDDA" ) {
@@ -244,8 +237,6 @@ bool Disc::execTarget( const QString &target )
 	return false;
 }
 
-
-
 void Disc::loadConfig( KConfig* config )
 {
 	QValueList<int> sl;
@@ -255,8 +246,6 @@ void Disc::loadConfig( KConfig* config )
 	split->setSizes( sl );
 }
 
-
-
 void Disc::saveConfig()
 {
 	KConfig* config = KGlobal::config();
@@ -265,22 +254,16 @@ void Disc::saveConfig()
 	config->writeEntry( "SplitSizes", split->sizes() );
 }
 
-
-
 QWidget* Disc::wantPlayerWindow()
 {
 	return playerBox;
 }
 
-
-
 QWidget* Disc::inputMainWidget()
 {
 	return mainWidget;
 }
 
-
-
 void Disc::setupActions()
 {
 	new KAction(i18n("Open &DVD"), "dvd_unmount", 0, this, SLOT(startDVD()), actionCollection(), "file_open_dvd");
@@ -288,8 +271,6 @@ void Disc::setupActions()
 	new KAction(i18n("Open &Audio-CD"), "cdaudio_unmount", 0, this, SLOT(startCD()), actionCollection(), "file_open_audiocd");
 }
 
-
-
 void Disc::playerStopped()
 {
 	trackCurrent = 0;
@@ -301,8 +282,6 @@ void Disc::playerStopped()
 	encodeWidget->hide();
 }
 
-
-
 void Disc::setEncoding( bool b )
 {
 	list->setEnabled( !b );
@@ -317,10 +296,12 @@ void Disc::setEncoding( bool b )
 	}
 	else
 		progressBar->hide();
+	if ( para ) {
+		delete para;
+		para = NULL;
+	}
 }
 
-
-
 void Disc::encode()
 {
 	QListViewItem *it;
@@ -340,18 +321,25 @@ void Disc::encode()
 		KMessageBox::information( mainWidget, i18n("You must select the tracks to rip."), i18n("Warning") );
 		return;
 	}
+	if ( !para ) {
+		if ( trackCurrent )
+			emit stop();
+		para = new Paranoia();
+		if ( !para->init( currentDevice ) ) {
+			KMessageBox::information( mainWidget, i18n("Unable to initialize cdparanoia."), i18n("Warning") );
+			delete para;
+			para = NULL;
+			return;
+		}
+	}
 	if ( para ) {
 		if ( para->encode( tracklist, mainWidget ) ) {
 			setEncoding( true );
-			if ( trackCurrent )
-				emit stop();
 			encodeTimer.start( 1000 );
 		}
 	}
 }
 
-
-
 void Disc::encodeProgress()
 {
 	if ( para->running() )
@@ -360,8 +348,6 @@ void Disc::encodeProgress()
 		setEncoding( false );
 }
 
-
-
 void Disc::setCurrent( int n )
 {
 	QListViewItem *it;
@@ -376,8 +362,6 @@ void Disc::setCurrent( int n )
 	}
 }
 
-
-
 void Disc::trackSelected( QListViewItem *it )
 {
 	if ( !it )
@@ -394,15 +378,11 @@ void Disc::trackSelected( QListViewItem *it )
 	emit play( mrl, this );
 }
 
-
-
 void Disc::startRIP()
 {
 	startCD( "", true );
 }
 
-
-
 void Disc::startCD( const QString &device, bool rip )
 {
 	QStringList s;
@@ -414,8 +394,11 @@ void Disc::startCD( const QString &device, bool rip )
 	QStringList dcopList, devList;
 	bool ok=false;
 
-	if ( progressBar->isVisible() )
+	if ( !cdBtn->isEnabled() ) {
+		emit showMe( this );
 		return;
+	}
+
 
 	if ( !device.isEmpty() )
 		s.append( device );
@@ -528,6 +511,8 @@ void Disc::startCD( const QString &device, bool rip )
 			mrl.setMime( QString("audio/cdda") );
 			trackCurrent = mrl.track().toInt();
 			setCurrent( trackCurrent );
+			delete para;
+			para = NULL;
 			emit play( mrl, this );
 		}
 	}
@@ -539,8 +524,6 @@ void Disc::startCD( const QString &device, bool rip )
 	}
 }
 
-
-
 void Disc::startDVD( const QString &device )
 {
 	MRL mrl;
@@ -601,8 +584,6 @@ void Disc::startDVD( const QString &device )
 	emit play( mrl, this );
 }
 
-
-
 void Disc::startVCD( const QString &device )
 {
 	MRL mrl;
@@ -657,8 +638,6 @@ void Disc::startVCD( const QString &device )
 	emit play( mrl, this );
 }
 
-
-
 bool Disc::currentTrack( MRL &mrl )
 {
 	QListViewItem *it;
@@ -686,15 +665,11 @@ bool Disc::currentTrack( MRL &mrl )
 	return false;
 }
 
-
-
 bool Disc::playbackFinished( MRL &mrl )
 {
 	return nextTrack( mrl );
 }
 
-
-
 bool Disc::nextTrack( MRL &mrl )
 {
 	QListViewItem *it;
@@ -732,8 +707,6 @@ bool Disc::nextTrack( MRL &mrl )
 	return true;
 }
 
-
-
 bool Disc::previousTrack( MRL &mrl )
 {
 	QListViewItem *it;
@@ -762,8 +735,6 @@ bool Disc::previousTrack( MRL &mrl )
 	return false;
 }
 
-
-
 bool Disc::trackNumber( int number, MRL &mrl )
 {
 	QListViewItem *it;
@@ -792,8 +763,6 @@ bool Disc::trackNumber( int number, MRL &mrl )
 	return false;
 }
 
-
-
-void Disc::mergeMeta(const MRL& mrl)
+void Disc::mergeMeta( const MRL& )
 {
 }
