@@ -1,7 +1,7 @@
 /*
  * dvbconfig.cpp
  *
- * Copyright (C) 2004-2006 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2004-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,8 @@
 #include "gdvb.h"
 #include "kaffeinedvbplugin.h"
 
+
+
 MSpinBox::MSpinBox( QWidget *parent, int devNum ) : QSpinBox( 1, 4, 1, parent )
 {
 	deviceNumber = devNum;
@@ -73,11 +75,30 @@ void MPushButton::isClicked()
 
 
 
+MComboBox::MComboBox( QWidget *parent, int devNum, int lnbNum ) : QComboBox( parent )
+{
+	deviceNumber = devNum;
+	lnbNumber = lnbNum;
+	connect( this, SIGNAL(activated(int)), this, SLOT(isActivated(int)) );
+}
+
+
+
+void MComboBox::isActivated( int index )
+{
+	emit activated( index, deviceNumber, lnbNumber );
+}
+
+
+
 LNB::LNB()
 {
 	switchFreq = 11700;
 	loFreq = 9750;
 	hiFreq = 10600;
+	rotorType = 0;
+	speed13v = 2.5;
+	speed18v = 1.5;
 }
 
 
@@ -90,6 +111,7 @@ Device::Device( int anum, int tnum, fe_type_t t, const QString &n, bool as )
 	name = n;
 	source = "";
 	canAutoscan= as;
+	tuningTimeout = 1500;
 }
 
 
@@ -112,6 +134,7 @@ DVBconfig::DVBconfig( const QString &dvbConf )
 		dir.mkdir( dvbConfigIconsDir );
 	config = new KConfig( dvbConfigDir+"dvbrc" );
 	downProgress = 0;
+	sizeFile = 0;
 	categories.setAutoDelete( true );
 	devList.setAutoDelete( true );
 	startup();
@@ -136,22 +159,24 @@ bool DVBconfig::haveDvbDevice()
 	struct dvb_frontend_info info;
 	fprintf(stderr,"%d\n", errno);
 
-	while ( i>=0 && i<10 ) {
+	QStringList list;
+	QDir d;
+	d.setPath( "/dev/dvb/" );
+	list = d.entryList( "adapter*", QDir::Dirs, QDir::Name );
+
+	for ( i=0; i<(int)list.count(); i++ ) {
 		j = 0;
 		while ( j>=0 && j<4 ) {
-			fdFrontend = open( QString("/dev/dvb/adapter%1/frontend%2").arg( i ).arg( j ).ascii(), O_RDWR);
+			fdFrontend = open( QString("/dev/dvb/%1/frontend%2").arg( list[i] ).arg( j ).ascii(), O_RDWR);
 			if ( fdFrontend<0 ) {
-				if ( errno==ENOENT ) {
-					if ( j==0 )
-						i = -1;
+				if ( errno==ENOENT )
 					j=-1;
-				}
 				else
 					++j;
 			}
 			else {
 				if ( (res = ioctl( fdFrontend, FE_GET_INFO, &info ) < 0) )
-					perror( QString("/dev/dvb/adapter%1/frontend%2 FE_GET_INFO: ").arg( i ).arg( j ).ascii() );
+					perror( QString("/dev/dvb/%1/frontend%2 FE_GET_INFO: ").arg( list[i] ).arg( j ).ascii() );
 				else {
 					close( fdFrontend );
 					return true;
@@ -160,8 +185,6 @@ bool DVBconfig::haveDvbDevice()
 				++j;
 			}
 		}
-		if ( i!=-1 )
-			++i;
 	}
 
 	return false;
@@ -175,40 +198,40 @@ void DVBconfig::startup()
 	struct dvb_frontend_info info;
 	bool as;
 
-	while ( i>=0 && i<10 ) {
+	QStringList list;
+	QDir d;
+	d.setPath( "/dev/dvb/" );
+	list = d.entryList( "adapter*", QDir::Dirs, QDir::Name );
+
+	for ( i=0; i<(int)list.count(); i++ ) {
 		j = 0;
 		while ( j>=0 && j<4 ) {
-			fdFrontend = open( QString("/dev/dvb/adapter%1/frontend%2").arg( i ).arg( j ).ascii(), O_RDWR);
+			fdFrontend = open( QString("/dev/dvb/%1/frontend%2").arg( list[i] ).arg( j ).ascii(), O_RDWR);
 			if ( fdFrontend<0 ) {
-				perror( QString("/dev/dvb/adapter%1/frontend%2 : ").arg( i ).arg( j ).ascii() );
-				if ( errno==ENOENT ) {
-					if ( j==0 )
-						i = -1;
+				perror( QString("/dev/dvb/%1/frontend%2 : ").arg( list[i] ).arg( j ).ascii() );
+				if ( errno==ENOENT )
 					j=-1;
-				}
 				else
 					++j;
 			}
 			else {
 				if ( !(res = ioctl( fdFrontend, FE_GET_INFO, &info ) < 0) ) {
-					if ( (info.caps & FE_CAN_FEC_AUTO)
+					if ( (info.type==FE_OFDM)
 						&& (info.caps & FE_CAN_QAM_AUTO)
 						&& (info.caps & FE_CAN_TRANSMISSION_MODE_AUTO)
 						&& (info.caps & FE_CAN_GUARD_INTERVAL_AUTO)
 						&& (info.caps & FE_CAN_HIERARCHY_AUTO)
-						&& (info.type==FE_OFDM) )
+						&& (info.caps & FE_CAN_FEC_AUTO) )
 						as = true;
 					else
 						as = false;
-					devList.append( new Device( i, j, info.type, info.name, as ) );
-					fprintf(stderr,"/dev/dvb/adapter%d/frontend%d : opened ( %s )\n", i, j, info.name );
+					fprintf(stderr,"/dev/dvb/%s/frontend%d : opened ( %s )\n", list[i].ascii(), j, info.name );
+					devList.append( new Device( list[i].replace("adapter","").toInt(), j, info.type, info.name, as ) );
 				}
 				close( fdFrontend );
 				++j;
 			}
 		}
-		if ( i!=-1 )
-			++i;
 	}
 
 	//devList.append( new Device( 0, 1, FE_QPSK, "Dummy S", false ) );
@@ -296,12 +319,12 @@ bool DVBconfig::haveData()
 
 
 
-QStringList DVBconfig::getSourcesList( int devNum )
+QStringList DVBconfig::getSourcesList( fe_type_t type )
 {
 	QString s;
 	QStringList list;
 
-	switch ( devList.at(devNum)->type ) {
+	switch ( type ) {
 		case FE_QPSK : s = "dvb-s"; break;
 		case FE_QAM : s = "dvb-c"; break;
 		case FE_OFDM : s = "dvb-t"; break;
@@ -398,24 +421,25 @@ void DVBconfig::readConfig()
 	recordDir = config->readEntry( "RecordDir", QDir::homeDirPath() );
 	if ( !recordDir.endsWith("/") )
 		recordDir+= "/";
+	sizeFile = config->readNumEntry("SizeFile",0);
 	shiftDir = config->readEntry( "ShiftDir", QDir::homeDirPath() );
 	if ( !shiftDir.endsWith("/") )
 		shiftDir+= "/";
 	for ( i=0; i<(int)devList.count(); i++ ) {
 		devList.at(i)->source = config->readEntry( QString("DVB%1").arg(i), "" );
-		if ( devList.at(i)->type==FE_QPSK ) {
-			devList.at(i)->lnb0.switchFreq = config->readNumEntry( QString("DVB%1_LNB0_switch").arg(i), 11700 );
-			devList.at(i)->lnb0.loFreq = config->readNumEntry( QString("DVB%1_LNB0_lo").arg(i), 9750 );
-			devList.at(i)->lnb0.hiFreq = config->readNumEntry( QString("DVB%1_LNB0_hi").arg(i), 10600 );
-			devList.at(i)->lnb1.switchFreq = config->readNumEntry( QString("DVB%1_LNB1_switch").arg(i), 11700 );
-			devList.at(i)->lnb1.loFreq = config->readNumEntry( QString("DVB%1_LNB1_lo").arg(i), 9750 );
-			devList.at(i)->lnb1.hiFreq = config->readNumEntry( QString("DVB%1_LNB1_hi").arg(i), 10600 );
-			devList.at(i)->lnb2.switchFreq = config->readNumEntry( QString("DVB%1_LNB2_switch").arg(i), 11700 );
-			devList.at(i)->lnb2.loFreq = config->readNumEntry( QString("DVB%1_LNB2_lo").arg(i), 9750 );
-			devList.at(i)->lnb2.hiFreq = config->readNumEntry( QString("DVB%1_LNB2_hi").arg(i), 10600 );
-			devList.at(i)->lnb3.switchFreq = config->readNumEntry( QString("DVB%1_LNB3_switch").arg(i), 11700 );
-			devList.at(i)->lnb3.loFreq = config->readNumEntry( QString("DVB%1_LNB3_lo").arg(i), 9750 );
-			devList.at(i)->lnb3.hiFreq = config->readNumEntry( QString("DVB%1_LNB3_hi").arg(i), 10600 );
+		devList.at(i)->tuningTimeout = config->readNumEntry( QString("DVB%1_TIMEOUT").arg(i), 1500 );
+		if ( devList.at(i)->type!=FE_QPSK )
+			continue;
+		devList.at(i)->numLnb = config->readNumEntry( QString("DVB%1_NLNB").arg(i), 1 );
+		for ( j=0; j<devList.at(i)->numLnb; j++ ) {
+			devList.at(i)->lnb[j].switchFreq = config->readNumEntry( QString("DVB%1_LNB%2_switch").arg(i).arg(j), 11700 );
+			devList.at(i)->lnb[j].loFreq = config->readNumEntry( QString("DVB%1_LNB%2_lo").arg(i).arg(j), 9750 );
+			devList.at(i)->lnb[j].hiFreq = config->readNumEntry( QString("DVB%1_LNB%2_hi").arg(i).arg(j), 10600 );
+			devList.at(i)->lnb[j].rotorType = config->readNumEntry( QString("DVB%1_LNB%2_rotor").arg(i).arg(j), 0 );
+			devList.at(i)->lnb[j].source = config->readListEntry( QString("DVB%1_LNB%2_source").arg(i).arg(j) );
+			devList.at(i)->lnb[j].position = config->readIntListEntry( QString("DVB%1_LNB%2_position").arg(i).arg(j) );
+			devList.at(i)->lnb[j].speed13v = config->readDoubleNumEntry( QString("DVB%1_LNB%2_speed13v").arg(i).arg(j), 2.5 );
+			devList.at(i)->lnb[j].speed18v = config->readDoubleNumEntry( QString("DVB%1_LNB%2_speed18v").arg(i).arg(j), 1.5 );
 		}
 	}
 	j = config->readNumEntry( "NumCategories", 0 );
@@ -427,13 +451,19 @@ void DVBconfig::readConfig()
 	lastChannel = config->readNumEntry( "LastChannel", 1 );
 	splitSizes = config->readIntListEntry("SplitSizes");
 	defaultCharset = config->readEntry( "DefaultCharset", "ISO8859-1" );
+	usalsLatitude = config->readDoubleNumEntry( "UsalsLatitude", 0.0 );
+	usalsLongitude = config->readDoubleNumEntry( "UsalsLongitude", 0.0 );
+	for ( i=0; i<(int)devList.count(); i++ ) {
+		devList.at(i)->usalsLatitude = usalsLatitude;
+		devList.at(i)->usalsLongitude = usalsLongitude;
+	}
 }
 
 
 
 void DVBconfig::saveConfig()
 {
-	int i;
+	int i, j;
 
 	config->setGroup( "DVB Options" );
 	config->writeEntry( "EPG Geometry", epgSize );
@@ -450,19 +480,19 @@ void DVBconfig::saveConfig()
 	config->writeEntry( "SenderPort", senderPort );
 	for ( i=0; i<(int)devList.count(); i++ ) {
 		config->writeEntry( QString("DVB%1").arg(i), devList.at(i)->source );
-		if ( devList.at(i)->type==FE_QPSK ) {
-			config->writeEntry( QString("DVB%1_LNB0_switch").arg(i), devList.at(i)->lnb0.switchFreq );
-			config->writeEntry( QString("DVB%1_LNB0_lo").arg(i), devList.at(i)->lnb0.loFreq );
-			config->writeEntry( QString("DVB%1_LNB0_hi").arg(i), devList.at(i)->lnb0.hiFreq );
-			config->writeEntry( QString("DVB%1_LNB1_switch").arg(i), devList.at(i)->lnb1.switchFreq );
-			config->writeEntry( QString("DVB%1_LNB1_lo").arg(i), devList.at(i)->lnb1.loFreq );
-			config->writeEntry( QString("DVB%1_LNB1_hi").arg(i), devList.at(i)->lnb1.hiFreq );
-			config->writeEntry( QString("DVB%1_LNB2_switch").arg(i), devList.at(i)->lnb2.switchFreq );
-			config->writeEntry( QString("DVB%1_LNB2_lo").arg(i), devList.at(i)->lnb2.loFreq );
-			config->writeEntry( QString("DVB%1_LNB2_hi").arg(i), devList.at(i)->lnb2.hiFreq );
-			config->writeEntry( QString("DVB%1_LNB3_switch").arg(i), devList.at(i)->lnb3.switchFreq );
-			config->writeEntry( QString("DVB%1_LNB3_lo").arg(i), devList.at(i)->lnb3.loFreq );
-			config->writeEntry( QString("DVB%1_LNB3_hi").arg(i), devList.at(i)->lnb3.hiFreq );
+		config->writeEntry( QString("DVB%1_TIMEOUT").arg(i), devList.at(i)->tuningTimeout );
+		if ( devList.at(i)->type!=FE_QPSK )
+			continue;
+		config->writeEntry( QString("DVB%1_NLNB").arg(i), devList.at(i)->numLnb );
+		for ( j=0; j<devList.at(i)->numLnb; j++ ) {
+			config->writeEntry( QString("DVB%1_LNB%2_switch").arg(i).arg(j), devList.at(i)->lnb[j].switchFreq );
+			config->writeEntry( QString("DVB%1_LNB%2_lo").arg(i).arg(j), devList.at(i)->lnb[j].loFreq );
+			config->writeEntry( QString("DVB%1_LNB%2_hi").arg(i).arg(j), devList.at(i)->lnb[j].hiFreq );
+			config->writeEntry( QString("DVB%1_LNB%2_rotor").arg(i).arg(j), devList.at(i)->lnb[j].rotorType );
+			config->writeEntry( QString("DVB%1_LNB%2_source").arg(i).arg(j), devList.at(i)->lnb[j].source );
+			config->writeEntry( QString("DVB%1_LNB%2_position").arg(i).arg(j), devList.at(i)->lnb[j].position );
+			config->writeEntry( QString("DVB%1_LNB%2_speed13v").arg(i).arg(j), devList.at(i)->lnb[j].speed13v );
+			config->writeEntry( QString("DVB%1_LNB%2_speed18v").arg(i).arg(j), devList.at(i)->lnb[j].speed18v );
 		}
 	}
 	config->writeEntry( "NumCategories", categories.count() );
@@ -476,6 +506,9 @@ void DVBconfig::saveConfig()
 	config->writeEntry( "LastChannel", lastChannel );
 	config->writeEntry( "SplitSizes", splitSizes );
 	config->writeEntry( "DefaultCharset", defaultCharset );
+	config->writeEntry( "UsalsLatitude", usalsLatitude );
+	config->writeEntry( "UsalsLongitude", usalsLongitude );
+	config->writeEntry( "SizeFile", sizeFile );
 	config->sync();
 }
 
@@ -484,8 +517,8 @@ void DVBconfig::saveConfig()
 bool DVBconfig::firstRun()
 {
 	config->setGroup( "DVB Options" );
-	if ( config->readNumEntry( "FirstRun", 0 )<2 ) {
-		config->writeEntry( "FirstRun", 2 );
+	if ( config->readNumEntry( "FirstRun", 0 )<3 ) {
+		config->writeEntry( "FirstRun", 3 );
 		return true;
 	}
 	return false;
@@ -503,20 +536,24 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 	int i;
 	QVBoxLayout *vb;
 	QGroupBox *gb;
-	QGridLayout *grid;
+	QGridLayout *grid, *sgrid;
 	QLabel *ident;
 	QLabel *dvbType;
 	int gridLine;
+	QFrame *page;
+	QSpinBox *spin;
+	KPushButton *usals;
+	QWidget *swidg;
+	QStringList rotorList; rotorList<<i18n("No rotor")<<i18n("USALS rotor")<<i18n("Positions rotor");
 
 	dvbConfig = dc;
-
-	dvbPage[0]=dvbPage[1]=dvbPage[2]=dvbPage[3]=0;
+	timeoutSpin.setAutoDelete( true );
 
 	for ( i=0; i<(int)dvbConfig->devList.count(); i++ ) {
-		dvbPage[i] = addPage( i18n("DVB Device")+" "+s.setNum( dvbConfig->devList.at(i)->adapter )+":"+s.setNum( dvbConfig->devList.at(i)->tuner ), i18n("Device Settings"),
+		page = addPage( i18n("DVB Device")+" "+QString("%1:%2").arg(dvbConfig->devList.at(i)->adapter).arg(dvbConfig->devList.at(i)->tuner), i18n("Device Settings"),
 			KGlobal::instance()->iconLoader()->loadIcon( "hwinfo", KIcon::NoGroup, KIcon::SizeMedium ) );
-		vb = new QVBoxLayout( dvbPage[i], 6, 6 );
-		gb = new QGroupBox( "", dvbPage[i] );
+		vb = new QVBoxLayout( page, 6, 6 );
+		gb = new QGroupBox( "", page );
 		grid = new QGridLayout( gb, 1, 1, 20, 6 );
 		gridLine = 0;
 
@@ -539,71 +576,155 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 		grid->addMultiCellWidget( dvbType, gridLine, gridLine, 1, 3 );
 		++gridLine;
 
+		lab = new QLabel( i18n("Tuner timeout :"), gb );
+		grid->addWidget( lab, gridLine, 0 );
+		spin = new QSpinBox( 500, 5000, 100, gb );
+		spin->setValue( dvbConfig->devList.at(i)->tuningTimeout );
+		timeoutSpin.append( spin );
+		grid->addWidget( spin, gridLine, 1 );
+		lab = new QLabel( i18n("(ms)"), gb );
+		grid->addWidget( lab, gridLine, 2 );
+		++gridLine;
+
 		if ( dvbConfig->devList.at(i)->type==FE_QPSK ) {
 			lab = new QLabel( i18n("Number of LNBs:"), gb );
 			grid->addWidget( lab, gridLine, 0 );
 			satNumber[i] = new MSpinBox( gb, i );
 			connect( satNumber[i], SIGNAL(signalValueChanged(int,int)), this, SLOT(satNumberChanged(int,int)));
 			grid->addWidget( satNumber[i], gridLine, 1 );
+			usals = new KPushButton( gb );
+			usals->setGuiItem( KGuiItem(i18n("Set rotor coordinates..."), icon->loadIconSet("move", KIcon::Small) ) );
+			connect( usals, SIGNAL(clicked()), this, SLOT(setUsals()));
+			grid->addWidget( usals, gridLine, 2 );
+
 			++gridLine;
 
-			lab = new QLabel( i18n("1st sat:"), gb );
-			grid->addWidget( lab, gridLine, 0 );
-			sat0[i] = new QComboBox( gb );
-			sat0[i]->setEnabled(true);
-			sat0[i]->insertStringList( dvbConfig->getSourcesList(i) );
-			setSource( sat0[i], dvbConfig->devList.at(i)->source, 0 );
-			grid->addWidget( sat0[i], gridLine, 1 );
 			lnb0[i] = new MPushButton( gb, i, 0 );
-			lnb0[i]->setGuiItem( KGuiItem(i18n("LNB Settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb0[i]->setGuiItem( KGuiItem(i18n("LNB 1 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
 			lnb0[i]->setEnabled(true);
-			grid->addWidget( lnb0[i], gridLine, 2 );
+			grid->addWidget( lnb0[i], gridLine, 0 );
 			connect( lnb0[i], SIGNAL(clicked(int,int)), this, SLOT(setLnb(int,int)));
+			rotor0[i] = new MComboBox( gb, i, 0 );
+			rotor0[i]->insertStringList( rotorList );
+			rotor0[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[0].rotorType );
+			grid->addWidget( rotor0[i], gridLine, 1 );
+			connect( rotor0[i], SIGNAL(activated(int,int,int)), this, SLOT(setRotor(int,int,int)));
+			swidg = new QWidget( gb );
+			sgrid = new QGridLayout( swidg, 1, 1, 0, 0 );
+			sat0[i] = new QComboBox( swidg );
+			sat0[i]->insertStringList( dvbConfig->getSourcesList(dvbConfig->devList.at(i)->type) );
+			sgrid->addWidget( sat0[i], 0, 0 );
+			src0[i] = new MPushButton( swidg, i, 0 );
+			src0[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
+			connect( src0[i], SIGNAL(clicked(int,int)), this, SLOT(setRotorSources(int,int)) );
+			sgrid->addWidget( src0[i], 1, 0 );
+			if ( dvbConfig->devList.at(i)->lnb[0].rotorType==0 ) {
+				setSource( sat0[i], dvbConfig->devList.at(i)->lnb[0].source[0] );
+				src0[i]->hide();
+			}
+			else {
+				sat0[i]->hide();
+			}
+			grid->addWidget( swidg, gridLine, 2 );
 			++gridLine;
 
-			lab = new QLabel( i18n("2nd sat:"), gb );
-			grid->addWidget( lab, gridLine, 0 );
-			sat1[i] = new QComboBox( gb );
-			sat1[i]->setEnabled(false);
-			sat1[i]->insertStringList( dvbConfig->getSourcesList(i) );
-			setSource( sat1[i], dvbConfig->devList.at(i)->source, 1 );
-			grid->addWidget( sat1[i], gridLine, 1 );
 			lnb1[i] = new MPushButton( gb, i, 1 );
-			lnb1[i]->setGuiItem( KGuiItem(i18n("LNB Settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb1[i]->setGuiItem( KGuiItem(i18n("LNB 2 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
 			lnb1[i]->setEnabled(false);
-			grid->addWidget( lnb1[i], gridLine, 2 );
+			grid->addWidget( lnb1[i], gridLine, 0 );
 			connect( lnb1[i], SIGNAL(clicked(int,int)), this, SLOT(setLnb(int,int)));
+			rotor1[i] = new MComboBox( gb, i, 1 );
+			rotor1[i]->setEnabled( false );
+			rotor1[i]->insertStringList( rotorList );
+			rotor1[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[1].rotorType );
+			grid->addWidget( rotor1[i], gridLine, 1 );
+			connect( rotor1[i], SIGNAL(activated(int,int,int)), this, SLOT(setRotor(int,int,int)));
+			swidg = new QWidget( gb );
+			sgrid = new QGridLayout( swidg, 1, 1, 0, 0 );
+			sat1[i] = new QComboBox( swidg );
+			sat1[i]->setEnabled(false);
+			sat1[i]->insertStringList( dvbConfig->getSourcesList(dvbConfig->devList.at(i)->type) );
+			sgrid->addWidget( sat1[i], 0, 0 );
+			src1[i] = new MPushButton( swidg, i, 1 );
+			src1[i]->setEnabled(false);
+			src1[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
+			connect( src1[i], SIGNAL(clicked(int,int)), this, SLOT(setRotorSources(int,int)) );
+			sgrid->addWidget( src1[i], 1, 0 );
+			if ( dvbConfig->devList.at(i)->lnb[1].rotorType==0 ) {
+				setSource( sat1[i], dvbConfig->devList.at(i)->lnb[1].source[0] );
+				src1[i]->hide();
+			}
+			else {
+				sat1[i]->hide();
+			}
+			grid->addWidget( swidg, gridLine, 2 );
 			++gridLine;
 
-			lab = new QLabel( i18n("3rd sat:"), gb );
-			grid->addWidget( lab, gridLine, 0 );
-			sat2[i] = new QComboBox( gb );
-			sat2[i]->setEnabled(false);
-			sat2[i]->insertStringList( dvbConfig->getSourcesList(i) );
-			setSource( sat2[i], dvbConfig->devList.at(i)->source, 2 );
-			grid->addWidget( sat2[i], gridLine, 1 );
 			lnb2[i] = new MPushButton( gb, i, 2 );
-			lnb2[i]->setGuiItem( KGuiItem(i18n("LNB Settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb2[i]->setGuiItem( KGuiItem(i18n("LNB 3 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
 			lnb2[i]->setEnabled(false);
-			grid->addWidget( lnb2[i], gridLine, 2 );
+			grid->addWidget( lnb2[i], gridLine, 0 );
 			connect( lnb2[i], SIGNAL(clicked(int,int)), this, SLOT(setLnb(int,int)));
+			rotor2[i] = new MComboBox( gb, i, 2 );
+			rotor2[i]->setEnabled(false);
+			rotor2[i]->insertStringList( rotorList );
+			rotor2[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[2].rotorType );
+			grid->addWidget( rotor2[i], gridLine, 1 );
+			connect( rotor2[i], SIGNAL(activated(int,int,int)), this, SLOT(setRotor(int,int,int)));
+			swidg = new QWidget( gb );
+			sgrid = new QGridLayout( swidg, 1, 1, 0, 0 );
+			sat2[i] = new QComboBox( swidg );
+			sat2[i]->setEnabled(false);
+			sat2[i]->insertStringList( dvbConfig->getSourcesList(dvbConfig->devList.at(i)->type) );
+			sgrid->addWidget( sat2[i], 0, 0 );
+			src2[i] = new MPushButton( swidg, i, 2 );
+			src2[i]->setEnabled(false);
+			src2[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
+			connect( src2[i], SIGNAL(clicked(int,int)), this, SLOT(setRotorSources(int,int)) );
+			sgrid->addWidget( src2[i], 1, 0 );
+			if ( dvbConfig->devList.at(i)->lnb[2].rotorType==0 ) {
+				setSource( sat2[i], dvbConfig->devList.at(i)->lnb[2].source[0] );
+				src2[i]->hide();
+			}
+			else {
+				sat2[i]->hide();
+			}
+			grid->addWidget( swidg, gridLine, 2 );
 			++gridLine;
 
-			lab = new QLabel( i18n("4th sat:"), gb );
-			grid->addWidget( lab, gridLine, 0 );
-			sat3[i] = new QComboBox( gb );
-			sat3[i]->setEnabled(false);
-			sat3[i]->insertStringList( dvbConfig->getSourcesList(i) );
-			setSource( sat3[i], dvbConfig->devList.at(i)->source, 3 );
-			grid->addWidget( sat3[i], gridLine, 1 );
 			lnb3[i] = new MPushButton( gb, i, 3 );
-			lnb3[i]->setGuiItem( KGuiItem(i18n("LNB settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb3[i]->setGuiItem( KGuiItem(i18n("LNB 4 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
 			lnb3[i]->setEnabled(false);
-			grid->addWidget( lnb3[i], gridLine, 2 );
+			grid->addWidget( lnb3[i], gridLine, 0 );
 			connect( lnb3[i], SIGNAL(clicked(int,int)), this, SLOT(setLnb(int,int)));
+			rotor3[i] = new MComboBox( gb, i, 3 );
+			rotor3[i]->setEnabled(false);
+			rotor3[i]->insertStringList( rotorList );
+			rotor3[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[3].rotorType );
+			grid->addWidget( rotor3[i], gridLine, 1 );
+			connect( rotor3[i], SIGNAL(activated(int,int,int)), this, SLOT(setRotor(int,int,int)));
+			swidg = new QWidget( gb );
+			sgrid = new QGridLayout( swidg, 1, 1, 0, 0 );
+			sat3[i] = new QComboBox( swidg );
+			sat3[i]->setEnabled(false);
+			sat3[i]->insertStringList( dvbConfig->getSourcesList(dvbConfig->devList.at(i)->type) );
+			sgrid->addWidget( sat3[i], 0, 0 );
+			src3[i] = new MPushButton( swidg, i, 3 );
+			src3[i]->setEnabled(false);
+			src3[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
+			connect( src3[i], SIGNAL(clicked(int,int)), this, SLOT(setRotorSources(int,int)) );
+			sgrid->addWidget( src3[i], 1, 0 );
+			if ( dvbConfig->devList.at(i)->lnb[3].rotorType==0 ) {
+				setSource( sat3[i], dvbConfig->devList.at(i)->lnb[3].source[0] );
+				src3[i]->hide();
+			}
+			else {
+				sat3[i]->hide();
+			}
+			grid->addWidget( swidg, gridLine, 2 );
 			++gridLine;
 
-			satNumber[i]->setValue( dvbConfig->devList.at(i)->source.contains("|") );
+			satNumber[i]->setValue( dvbConfig->devList.at(i)->numLnb );
 		}
 		else {
 			lab = new QLabel( i18n("Source:"), gb );
@@ -611,8 +732,8 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 			sat0[i] = new QComboBox( gb );
 			if ( dvbConfig->devList.at(i)->canAutoscan )
 				sat0[i]->insertItem( "AUTO" );
-			sat0[i]->insertStringList( dvbConfig->getSourcesList(i) );
-			setSource( sat0[i], dvbConfig->devList.at(i)->source, 0 );
+			sat0[i]->insertStringList( dvbConfig->getSourcesList(dvbConfig->devList.at(i)->type) );
+			setSource( sat0[i], dvbConfig->devList.at(i)->source );
 			grid->addWidget( sat0[i], gridLine, 1 );
 			++gridLine;
 
@@ -636,10 +757,10 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 		vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
 	}
 
-	recordPage = addPage(i18n("Recording"),i18n("DVB Recording Options"),
+	page = addPage(i18n("Recording"),i18n("DVB Recording Options"),
 		KGlobal::instance()->iconLoader()->loadIcon( "hdd_unmount", KIcon::NoGroup, KIcon::SizeMedium ) );
-	vb = new QVBoxLayout( recordPage, 6, 6 );
-	gb = new QGroupBox( "", recordPage );
+	vb = new QVBoxLayout( page, 6, 6 );
+	gb = new QGroupBox( "", page );
 	grid = new QGridLayout( gb, 1, 1, 20, 6 );
 
 	lab = new QLabel( i18n("Records directory:"), gb );
@@ -692,6 +813,16 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 	formatComb = new QComboBox( gb );
 	grid->addWidget( formatComb, 5, 1 );
 
+	lab = new QLabel( i18n("Max file size (0=Unlimited):"), gb );
+	grid->addWidget( lab, 6, 0 );
+	sizeFileSpin = new QSpinBox( 1, 9999, 1, gb );
+	sizeFileSpin->setMinValue(0);
+	h1 = new QHBoxLayout();
+	h1->addWidget( sizeFileSpin );
+	lab = new QLabel( i18n("(MB)"), gb );
+	h1->addWidget( lab );
+	grid->addLayout( h1, 6, 1 );
+
 	vb->addWidget( gb );
 	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
 
@@ -700,6 +831,7 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 	beginSpin->setValue( dvbConfig->beginMargin );
 	endSpin->setValue( dvbConfig->endMargin );
 	instantDurationSpin->setValue( dvbConfig->instantDuration );
+	sizeFileSpin->setValue( dvbConfig->sizeFile );
 	formatComb->insertItem( "TS" );
 	formatComb->insertItem( "MPEG_PES" );
 	formatComb->insertItem( "MPEG_PS" );
@@ -709,10 +841,10 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 		case OutPS : formatComb->setCurrentItem( 2 ); break;
 	}
 
-	broadcastPage = addPage(i18n("Broadcasting"),i18n("DVB Broadcasting"),
+	page = addPage(i18n("Broadcasting"),i18n("DVB Broadcasting"),
 		KGlobal::instance()->iconLoader()->loadIcon( "network_local", KIcon::NoGroup, KIcon::SizeMedium ) );
-	vb = new QVBoxLayout( broadcastPage, 6, 6 );
-	gb = new QGroupBox( "", broadcastPage );
+	vb = new QVBoxLayout( page, 6, 6 );
+	gb = new QGroupBox( "", page );
 	grid = new QGridLayout( gb, 1, 1, 20, 6 );
 
 	lab = new QLabel( i18n("Broadcast address:"), gb );
@@ -735,10 +867,10 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 	bportSpin->setValue( dvbConfig->broadcastPort );
 	sportSpin->setValue( dvbConfig->senderPort );
 
-	miscPage = addPage(i18n("Misc"),i18n("Misc"),
+	page = addPage(i18n("Misc"),i18n("Misc"),
 		KGlobal::instance()->iconLoader()->loadIcon( "misc", KIcon::NoGroup, KIcon::SizeMedium ) );
-	vb = new QVBoxLayout( miscPage, 6, 6 );
-	gb = new QGroupBox( "", miscPage );
+	vb = new QVBoxLayout( page, 6, 6 );
+	gb = new QGroupBox( "", page );
 	grid = new QGridLayout( gb, 1, 1, 20, 6 );
 
 	lab = new QLabel( i18n("Default charset (restart needed):"), gb );
@@ -768,10 +900,10 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
 
 	if ( p ) {
-		QFrame *pluginPage = addPage(i18n("DVB plugins"),i18n("DVB plugins"),
+		page = addPage(i18n("DVB plugins"),i18n("DVB plugins"),
 			KGlobal::instance()->iconLoader()->loadIcon( "misc", KIcon::NoGroup, KIcon::SizeMedium ) );
-		vb = new QVBoxLayout( pluginPage, 6, 6 );
-		gb = new QGroupBox( "", pluginPage );
+		vb = new QVBoxLayout( page, 6, 6 );
+		gb = new QGroupBox( "", page );
 		grid = new QGridLayout( gb, 1, 1, 20, 6 );
 
 		KPushButton *btn = new KPushButton( p->pluginName(), gb );
@@ -789,28 +921,82 @@ DvbConfigDialog::DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlu
 
 
 
-void DvbConfigDialog::setLnb( int devNum, int lnbNum )
+void DvbConfigDialog::setUsals()
 {
-	LNB *b;
+	KDialogBase *dlg = new KDialogBase( this, "usalsConfigDialog", true, i18n("Rotors settings"), Ok|Cancel, Ok, true );
+	QGridLayout *grid;
+	QWidget *page = new QWidget( dlg );
+	dlg->setMainWidget( page );
+
+	QVBoxLayout *vb = new QVBoxLayout( page, 6, 6 );
+	QLabel *lab = new QLabel( i18n("Set your position coordinates for rotors:"), page );
+	vb->addWidget( lab );
+	lab = new QLabel( "(Sydney: -33.8916, 151.2417 - New York: 40.7139, -74.0063)", page );
+	vb->addWidget( lab );
+	grid = new QGridLayout( 0, 1, 1 );
+	lab = new QLabel( i18n("Latitude:"), page );
+	grid->addWidget( lab, 0, 0 );
+	QLineEdit *latitude = new QLineEdit( page );
+	latitude->setText( QString().setNum( dvbConfig->usalsLatitude ) );
+	grid->addWidget( latitude, 0, 1 );
+	lab = new QLabel( i18n("Longitude:"), page );
+	grid->addWidget( lab, 1, 0 );
+	QLineEdit *longitude = new QLineEdit( page );
+	longitude->setText( QString().setNum( dvbConfig->usalsLongitude ) );
+	grid->addWidget( longitude, 1, 1 );
+	vb->addLayout( grid );
+	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
+
+	if ( dlg->exec()==QDialog::Accepted ) {
+		dvbConfig->usalsLatitude = latitude->text().toDouble();
+		dvbConfig->usalsLongitude = longitude->text().toDouble();
+		for ( int i=0; i<(int)dvbConfig->devList.count(); i++ ) {
+			dvbConfig->devList.at(i)->usalsLatitude = dvbConfig->usalsLatitude;
+			dvbConfig->devList.at(i)->usalsLongitude = dvbConfig->usalsLongitude;
+		}
+	}
+}
+
+
+
+void DvbConfigDialog::setRotorSources( int devNum, int lnbNum )
+{
+	RotorConfig rotor( dvbConfig->devList.at(devNum), dvbConfig, lnbNum, this );
+	rotor.exec();
+}
+
+
+
+void DvbConfigDialog::setRotor( int index, int devNum, int lnbNum )
+{
+	QComboBox *comb;
+	QPushButton *btn;
 
 	switch ( lnbNum ) {
-		case 0 :
-			b = &dvbConfig->devList.at(devNum)->lnb0;
-			break;
-		case 1 :
-			b = &dvbConfig->devList.at(devNum)->lnb1;
-			break;
-		case 2 :
-			b = &dvbConfig->devList.at(devNum)->lnb2;
-			break;
-		case 3 :
-			b = &dvbConfig->devList.at(devNum)->lnb3;
-			break;
-		default :
-			return;
+		case 0 : comb=sat0[devNum]; btn=src0[devNum]; break;
+		case 1 : comb=sat1[devNum]; btn=src1[devNum]; break;
+		case 2 : comb=sat2[devNum]; btn=src2[devNum]; break;
+		case 3 : comb=sat3[devNum]; btn=src3[devNum]; break;
+		default : return;
 	}
 
-	LnbConfig lnb( b, this );
+	dvbConfig->devList.at(devNum)->lnb[lnbNum].rotorType=index;
+
+	if ( index==0 ) {
+		btn->hide();
+		comb->show();
+	}
+	else {
+		comb->hide();
+		btn->show();
+	}
+}
+
+
+
+void DvbConfigDialog::setLnb( int devNum, int lnbNum )
+{
+	LnbConfig lnb( &dvbConfig->devList.at(devNum)->lnb[lnbNum], this );
 	lnb.exec();
 }
 
@@ -833,19 +1019,15 @@ loop:
 
 
 
-void DvbConfigDialog::setSource( QComboBox *box, QString s, int sat )
+void DvbConfigDialog::setSource( QComboBox *box, QString s )
 {
-	QString c;
 	int pos, i;
 
-	for ( i=0; i<sat+1; i++ ) {
-		pos = s.find("|");
-		s = s.right( s.length()-pos-1 );
-	}
 	pos = s.find("|");
-	c = s.left(pos);
+	if ( pos>=0 )
+		s = s.right( s.length()-pos-1 );
 	for ( i=0; i<(int)box->count(); i++ ) {
-		if ( box->text(i)==c ) {
+		if ( box->text(i)==s ) {
 			box->setCurrentItem(i);
 			break;
 		}
@@ -861,10 +1043,20 @@ void DvbConfigDialog::satNumberChanged( int value, int devNum )
 	sat2[devNum]->setEnabled( value > 2 );
 	sat3[devNum]->setEnabled( value > 3 );
 
+	src0[devNum]->setEnabled( value > 0 );
+	src1[devNum]->setEnabled( value > 1 );
+	src2[devNum]->setEnabled( value > 2 );
+	src3[devNum]->setEnabled( value > 3 );
+
 	lnb0[devNum]->setEnabled( value > 0 );
 	lnb1[devNum]->setEnabled( value > 1 );
 	lnb2[devNum]->setEnabled( value > 2 );
 	lnb3[devNum]->setEnabled( value > 3 );
+
+	rotor0[devNum]->setEnabled( value > 0 );
+	rotor1[devNum]->setEnabled( value > 1 );
+	rotor2[devNum]->setEnabled( value > 2 );
+	rotor3[devNum]->setEnabled( value > 3 );
 }
 
 
@@ -916,11 +1108,24 @@ void DvbConfigDialog::accept()
 	for ( i=0; i<(int)dvbConfig->devList.count(); i++ ) {
 		switch (dvbConfig->devList.at(i)->type) {
 		case FE_QPSK: {
+			dvbConfig->devList.at(i)->numLnb = satNumber[i]->value();
+			if ( dvbConfig->devList.at(i)->lnb[3].rotorType==0 ) {
+				dvbConfig->devList.at(i)->lnb[3].source.clear();
+				dvbConfig->devList.at(i)->lnb[3].source.append(sat3[i]->currentText());
+			}
+			if ( dvbConfig->devList.at(i)->lnb[2].rotorType==0 ) {
+				dvbConfig->devList.at(i)->lnb[2].source.clear();
+				dvbConfig->devList.at(i)->lnb[2].source.append(sat2[i]->currentText());
+			}
+			if ( dvbConfig->devList.at(i)->lnb[1].rotorType==0 ) {
+				dvbConfig->devList.at(i)->lnb[1].source.clear();
+				dvbConfig->devList.at(i)->lnb[1].source.append(sat1[i]->currentText());
+			}
+			if ( dvbConfig->devList.at(i)->lnb[0].rotorType==0 ) {
+				dvbConfig->devList.at(i)->lnb[0].source.clear();
+				dvbConfig->devList.at(i)->lnb[0].source.append(sat0[i]->currentText());
+			}
 			s = "S";
-			if ( sat0[i]->isEnabled() ) s+="|"+sat0[i]->currentText();
-			if ( sat1[i]->isEnabled() ) s+="|"+sat1[i]->currentText();
-			if ( sat2[i]->isEnabled() ) s+="|"+sat2[i]->currentText();
-			if ( sat3[i]->isEnabled() ) s+="|"+sat3[i]->currentText();
 			break;
 			}
 		case FE_QAM: {
@@ -940,6 +1145,7 @@ void DvbConfigDialog::accept()
 			}
 		}
 		dvbConfig->devList.at(i)->source = s;
+		dvbConfig->devList.at(i)->tuningTimeout = timeoutSpin.at(i)->value();
 	}
 
 	dvbConfig->recordDir = recordDirLe->text();
@@ -951,6 +1157,7 @@ void DvbConfigDialog::accept()
 	dvbConfig->beginMargin = beginSpin->value();
 	dvbConfig->endMargin = endSpin->value();
 	dvbConfig->instantDuration = instantDurationSpin->value();
+	dvbConfig->sizeFile = sizeFileSpin->value();
 	switch ( formatComb->currentItem() ) {
 		case 0 : dvbConfig->format = OutTS; break;
 		case 1 : dvbConfig->format = OutPES; break;
@@ -1162,4 +1369,120 @@ void LnbConfig::accept()
 	done( Accepted );
 }
 
+
+
+RotorConfig::RotorConfig( Device *d, DVBconfig *c, int lnb, QWidget *parent ) :
+	KDialogBase ( parent, "rotorConfigDialog", true, i18n("Rotor Settings"), Ok|Cancel, Ok, true )
+{
+	int i;
+
+	QWidget *page = new QWidget( this );
+	setMainWidget( page );
+
+	dev = d;
+	config = c;
+	lnbNum = lnb;
+
+	QVBoxLayout *vb = new QVBoxLayout( page, 6, 6 );
+	QGridLayout *grid = new QGridLayout( 0, 1, 1 );
+	QLabel *lab = new QLabel( i18n("Sattelite:"), page );
+	grid->addWidget( lab, 0, 0 );
+	if ( dev->lnb[lnbNum].rotorType==2 ) {
+		lab = new QLabel( i18n("Position:"), page );
+		grid->addWidget( lab, 0, 1 );
+	}
+	srcComb = new QComboBox( page );
+	srcComb->insertStringList( config->getSourcesList( dev->type ) );
+	grid->addWidget( srcComb, 1, 0 );
+	position = new QSpinBox( 0, 500, 1, page );
+	grid->addWidget( position, 1, 1 );
+	vb->addLayout( grid );
+	vb->addItem( new QSpacerItem( 20, 10, QSizePolicy::Fixed, QSizePolicy::Fixed ) );
+
+	addBtn = new QPushButton( i18n("Add to list"), page );
+	connect( addBtn, SIGNAL(clicked()), this, SLOT(add()) );
+	vb->addWidget( addBtn );
+	vb->addItem( new QSpacerItem( 20, 10, QSizePolicy::Fixed, QSizePolicy::Fixed ) );
+
+	listView = new QListView( page );
+	listView->addColumn( i18n("Sattelite:") );
+	vb->addWidget( listView );
+
+	resetBtn = new QPushButton( i18n("Clear list"), page );
+	connect( resetBtn, SIGNAL(clicked()), this, SLOT(reset()) );
+	vb->addWidget( resetBtn );
+	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Fixed, QSizePolicy::Fixed ) );
+
+	grid = new QGridLayout( 0, 1, 1 );
+	lab = new QLabel( i18n("13V rotor speed:"), page );
+	grid->addWidget( lab, 0, 0 );
+	speed13 = new QLineEdit( page );
+	speed13->setText( QString().setNum( dev->lnb[lnbNum].speed13v ) );
+	grid->addWidget( speed13, 0, 1 );
+	lab = new QLabel( i18n("sec./ °"), page );
+	grid->addWidget( lab, 0, 2 );
+	lab = new QLabel( i18n("18V rotor speed:"), page );
+	grid->addWidget( lab, 1, 0 );
+	speed18 = new QLineEdit( page );
+	speed18->setText( QString().setNum( dev->lnb[lnbNum].speed18v ) );
+	grid->addWidget( speed18, 1, 1 );
+	lab = new QLabel( i18n("sec./ °"), page );
+	grid->addWidget( lab, 1, 2 );
+	vb->addLayout( grid );
+
+	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
+
+	if ( dev->lnb[lnbNum].rotorType==2 ) {
+		listView->addColumn( i18n("Position:") );
+		for ( i=0; i<(int)dev->lnb[lnbNum].source.count(); i++ )
+			new QListViewItem( listView, dev->lnb[lnbNum].source[i], QString().setNum(dev->lnb[lnbNum].position[i])  );
+	}
+	else {
+		position->hide();
+		for ( i=0; i<(int)dev->lnb[lnbNum].source.count(); i++ )
+			new QListViewItem( listView, dev->lnb[lnbNum].source[i] );
+	}
+
+}
+
+
+
+void RotorConfig::reset()
+{
+	listView->clear();
+	position->setValue( 1 );
+}
+
+
+
+void RotorConfig::add()
+{
+	if ( position->isHidden() ) {
+		new QListViewItem( listView, srcComb->currentText() );
+	}
+	else {
+		new QListViewItem( listView, srcComb->currentText(), QString().setNum(position->value()) );
+	}
+
+}
+
+
+
+void RotorConfig::accept()
+{
+	QListViewItem *it;
+
+	dev->lnb[lnbNum].speed18v = speed18->text().toDouble();
+	dev->lnb[lnbNum].speed13v = speed13->text().toDouble();
+	dev->lnb[lnbNum].source.clear();
+	dev->lnb[lnbNum].position.clear();
+	for ( it=listView->firstChild(); it; it=it->nextSibling() ) {
+		dev->lnb[lnbNum].source.append( it->text(0) );
+		if ( dev->lnb[lnbNum].rotorType==2 )
+			dev->lnb[lnbNum].position.append( it->text(1).toInt() );
+	}
+	done( Accepted );
+}
+
+
 #include "dvbconfig.moc"
