@@ -1,7 +1,7 @@
 /*
  * dvbconfig.h
  *
- * Copyright (C) 2004-2005 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2004-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <qcombobox.h>
 #include <qtoolbutton.h>
 #include <qbuttongroup.h>
+#include <qlistview.h>
 
 #include <kdialogbase.h>
 #include <kpushbutton.h>
@@ -69,6 +70,22 @@ private:
 
 
 
+class MComboBox : public QComboBox
+{
+	Q_OBJECT
+public:
+	MComboBox( QWidget *parent, int devNum, int lnbNum );
+private slots:
+	void isActivated( int index );
+signals:
+	void activated( int index, int devnum, int lnbnum );
+private:
+	int deviceNumber;
+	int lnbNumber;
+};
+
+
+
 class LNB
 {
 public:
@@ -77,6 +94,11 @@ public:
 	unsigned int switchFreq;
 	unsigned int loFreq;
 	unsigned int hiFreq;
+	int rotorType;
+	double speed13v, speed18v;
+	QStringList source;
+	QValueList<int> position;
+	QString currentSource;
 };
 
 
@@ -89,8 +111,11 @@ public:
 	fe_type_t type;
 	QString name;
 	QString source;
-	LNB lnb0, lnb1, lnb2, lnb3;
+	int numLnb;
+	LNB lnb[4];
 	bool canAutoscan;
+	int tuningTimeout;
+	double usalsLatitude, usalsLongitude;
 };
 
 
@@ -121,7 +146,7 @@ public:
 	static bool haveDvbDevice();
 	bool loadDvbData( QWidget *parent );
 	bool localData();
-	QStringList getSourcesList( int devNum );
+	QStringList getSourcesList( fe_type_t type );
 	bool haveData();
 	bool firstRun();
 	void addCategory( const QString &name, const QString &icon );
@@ -130,7 +155,7 @@ public:
 
 	KConfig *config;
 	QString recordDir, shiftDir;
-	int beginMargin, endMargin, format, instantDuration;
+	int beginMargin, endMargin, format, instantDuration, sizeFile;
 	QSize epgSize, scanSize, timerSize;
 	QPtrList<Device> devList;
 	QPtrList<Category> categories;
@@ -142,6 +167,7 @@ public:
 	int lastChannel;
 	QValueList<int> splitSizes;
 	QString defaultCharset;
+	double usalsLatitude, usalsLongitude;
 
 private:
 
@@ -166,25 +192,33 @@ public:
 
 	DvbConfigDialog( DVBconfig *dc, QWidget *parent, KaffeineDvbPlugin *p );
 	~DvbConfigDialog();
-	void setSource( QComboBox *box, QString s, int sat );
+	void setSource( QComboBox *box, QString s );
 
 	QLineEdit *recordDirLe, *shiftDirLe, *broadcastLe;
-	QSpinBox *beginSpin, *endSpin, *instantDurationSpin, *bportSpin, *sportSpin;
-	QSpinBox *satNumber[4];
-	QComboBox *sat0[4];
-	QComboBox *sat1[4];
-	QComboBox *sat2[4];
-	QComboBox *sat3[4];
-	MPushButton *lnb0[4];
-	MPushButton *lnb1[4];
-	MPushButton *lnb2[4];
-	MPushButton *lnb3[4];
+	QSpinBox *beginSpin, *endSpin, *instantDurationSpin, *bportSpin, *sportSpin, *sizeFileSpin;
+	MSpinBox *satNumber[8];
+	QComboBox *sat0[8];
+	QComboBox *sat1[8];
+	QComboBox *sat2[8];
+	QComboBox *sat3[8];
+	MPushButton *src0[8];
+	MPushButton *src1[8];
+	MPushButton *src2[8];
+	MPushButton *src3[8];
+	MComboBox *rotor0[8];
+	MComboBox *rotor1[8];
+	MComboBox *rotor2[8];
+	MComboBox *rotor3[8];
+	MPushButton *lnb0[8];
+	MPushButton *lnb1[8];
+	MPushButton *lnb2[8];
+	MPushButton *lnb3[8];
 	QComboBox *formatComb;
 	KPushButton *updateBtn, *dumpBtn;
 	QToolButton *recordDirBtn, *shiftDirBtn;
-	QFrame *broadcastPage, *miscPage, *recordPage, *dvbPage[4];
 	DVBconfig *dvbConfig;
 	QComboBox *charsetComb;
+	QPtrList<QSpinBox> timeoutSpin;
 
 private slots:
 
@@ -193,6 +227,9 @@ private slots:
 	void satNumberChanged( int value, int devNum );
 	void downloadData();
 	void setLnb( int devNum, int lnbNum );
+	void setRotor( int index, int devNum, int lnbNum );
+	void setRotorSources( int devNum, int lnbNum );
+	void setUsals();
 
 protected slots:
 
@@ -228,4 +265,37 @@ private:
 	LNB *lnb;
 };
 
+
+
+class RotorConfig : public KDialogBase
+{
+	Q_OBJECT
+
+public:
+
+	RotorConfig( Device *d, DVBconfig *c, int lnb, QWidget *parent );
+
+protected slots:
+
+	virtual void accept();
+
+private slots:
+
+	void reset();
+	void add();
+
+private:
+
+	QSpinBox *position;
+	QComboBox *srcComb;
+	QListView *listView;
+	QPushButton *addBtn, *resetBtn;
+	QLineEdit *speed13, *speed18;
+
+	Device *dev;
+	int lnbNum;
+	DVBconfig *config;
+};
+
+
 #endif /* DVBCONFIG_H */
