@@ -1,20 +1,22 @@
-/***************************************************************************
-                          dvbsi.cpp  -  description
-                             -------------------
-    begin                : 2004
-    copyright            : (C) 2003-2005 by Christophe Thommeret
-    email                : hftom@free.fr
-    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * dvbsi.cpp
+ *
+ * Copyright (C) 2003-2007 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <stdio.h>
 #include <unistd.h>
@@ -46,6 +48,7 @@ NitSection::NitSection( QPtrList<Transponder> *tp, bool *end, bool *ok, int anum
 
 NitSection::~NitSection()
 {
+	stop();
 }
 
 
@@ -392,7 +395,7 @@ bool DVBsi::tableSDT( unsigned char* buf )
 		channels.append( desc );
 		desc->tp.tsid = tsid;
 		desc->sid = getBits(buf,0,16);
-		desc->fta = getBits(buf,27,1 );
+		//desc->fta = getBits(buf,27,1 );
 		loop = getBits(buf,28,12);
 		buf +=5;
 		length -=(5+loop);
@@ -440,7 +443,19 @@ bool DVBsi::tablePMT( unsigned char* buf )
 	length = getBits(buf,12,12);
 	loop = getBits(buf+10,4,12);
 	length -=(9+loop);
-	buf +=12+loop;
+	buf +=12;
+
+	while ( loop>0 ) {
+		switch ( getBits(buf,0,8) ) {
+			case 0x09 :
+				desc->fta = 1;
+				break;
+			default :
+				break;
+		}
+		loop -=( getBits(buf,8,8)+2 );
+		buf +=( getBits(buf,8,8)+2 );
+	}
 
 	while ( length>4 ) {
 		type = getBits(buf,0,8);
@@ -464,6 +479,9 @@ bool DVBsi::tablePMT( unsigned char* buf )
 		length -=(5+loop);
 		while ( loop>0 ) {
 			switch ( getBits(buf,0,8) ) {
+				case 0x09 :
+					desc->fta = 1;
+					break;
 				case 0x0A :
 					lang = langDesc( buf );
 					if ( (type==3 || type==4) && nlang<=desc->maxapid ) {
@@ -540,13 +558,14 @@ bool DVBsi::tablePAT( unsigned char *buf )
 
 
 
-bool DVBsi::getSection( int pid, int tid, int timeout )
+bool DVBsi::getSection( int pid, int tid, int timeout, int sid )
 {
 	unsigned char buf[4096];
 	int i, n=0;
 	int skip=0;
 	int last=1, current=0, loop=0;
-	QValueList<int> list;
+	QValueList<int> list, sidList;
+	int cursid;
 
 	if ( !setFilter( pid, tid, timeout ) )
 		return false;
@@ -569,6 +588,12 @@ bool DVBsi::getSection( int pid, int tid, int timeout )
 			return false;
 		}
 
+		cursid = getBits(buf+3,0,16);
+		if ( sid && cursid!=sid && !sidList.contains(cursid) ) {
+			sidList.append( cursid );
+			continue;
+		}
+
 		last = getBits(buf,56,8);
 		current = getBits(buf,48,8);
 		for ( i=0; i<(int)list.count(); i++ ) {
@@ -717,7 +742,8 @@ void DVBsi::run()
 				nitEnded = false;
 				ns = new NitSection( &transponders, &nitEnded, &ok, adapter, tuner ); //NIT
 			}
-			getSection( 0x11, 0x42 );         //SDT
+			if ( !getSection( 0x11, 0x42 ) )         //SDT
+				continue;
 			if ( !isRunning ) {
 				out();
 				return;
@@ -732,7 +758,7 @@ void DVBsi::run()
 					out();
 					return;
 				}
-				getSection( channels.at( j )->pmtpid, 0x02 );    //PMTs
+				getSection( channels.at( j )->pmtpid, 0x02, 5000, channels.at( j )->sid );    //PMTs
 				tsid = channels.at(j)->tp.tsid;
 				channels.at(j)->tp = *transponders.at(i);
 				if ( channels.at(j)->tp.tsid==0 )
@@ -771,7 +797,7 @@ void DVBsi::run()
 				out(false);
 				return;
 			}
-			getSection( channels.at( j )->pmtpid, 0x02 );    //PMTs
+			getSection( channels.at( j )->pmtpid, 0x02, 5000, channels.at( j )->sid );    //PMTs
 			tsid = channels.at(j)->tp.tsid;
 			channels.at(j)->tp = trans;
 			channels.at(j)->tp.tsid = tsid;
