@@ -1,7 +1,7 @@
 /*
  * kevents.cpp
  *
- * Copyright (C) 2004-2006 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2004-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 #include <qpopupmenu.h>
 #include <qcursor.h>
 #include <qwhatsthis.h>
+#include <qcheckbox.h>
+#include <qtooltip.h>
 
 #include <klocale.h>
 #include <kiconloader.h>
@@ -58,15 +60,17 @@ int EListViewItem::compare( QListViewItem *i, int col, bool ascending ) const
 
 
 
-KEvents::KEvents( QPtrList<ChannelDesc> *chans, QPtrList<DvbStream> *d, QWidget *parent, QSize size ) : QDialog( parent )
+KEvents::KEvents( QPtrList<ChannelDesc> *chans, QPtrList<DvbStream> *d, EventTable *t, QWidget *parent, QSize size ) : QDialog( parent )
 {
 	dvb = d;
+	events = t;
 	channels = chans;
 
-	setCaption( i18n("EPG") );
+	setCaption( i18n("Electronic Program Guide") );
 
 	QGridLayout *grid = new QGridLayout( this, 1, 1, 11, 6, "grid");
 	QHBoxLayout *hbox = new QHBoxLayout( 0, 0, 6, "hbox" );
+	QVBoxLayout *vbox = new QVBoxLayout( 0, 0, 6 , "vbox");
 
 	resetBtn = new KPushButton( i18n("Refresh"), this );
 	hbox->addWidget( resetBtn );
@@ -74,12 +78,45 @@ KEvents::KEvents( QPtrList<ChannelDesc> *chans, QPtrList<DvbStream> *d, QWidget
 	hbox->addWidget( allBtn );
 	currentNextBtn = new KPushButton( i18n("Current/Next"), this );
 	hbox->addWidget( currentNextBtn );
-	currentChannelEpg = new KPushButton( i18n("Current Channel"), this );
-	hbox->addWidget( currentChannelEpg );
+	currentChannelEpgBtn = new KPushButton( i18n("Current Channel"), this );
+	hbox->addWidget( currentChannelEpgBtn );
 
 	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	hbox->addItem( spacer );
-	grid->addLayout( hbox, 0, 0 );
+
+	vbox->addLayout( hbox);
+
+	hbox = new QHBoxLayout();
+
+	searchBtn = new QToolButton( this );
+	searchBtn->setAutoRaise( true );
+	QToolTip::add( searchBtn, i18n("Electronic Program Guide Search"));
+	hbox->addWidget( searchBtn );
+
+	QLabel* filterLabel = new QLabel( i18n("Search") + ":", this );
+	hbox->addWidget( filterLabel );
+
+	searchLineEdit = new KLineEdit(this);
+	hbox->addWidget( searchLineEdit );
+
+	tvradioCb  = new QCheckBox(i18n("TV "), this );
+	QToolTip::add( tvradioCb, i18n("Search TV Channels only (omit Radio)"));
+	tvradioCb->setChecked(true);
+	hbox->addWidget( tvradioCb);
+
+	titleCb  = new QCheckBox(i18n("Titles "), this );
+	QToolTip::add( titleCb, i18n("Search Event Titles only (omit Description)"));
+	titleCb->setChecked(true);
+	hbox->addWidget( titleCb);
+
+	ftaCb  = new QCheckBox(i18n("FTA "), this );
+	QToolTip::add( ftaCb, i18n("Search Free to Air Channels only (omit PayTV)"));
+	ftaCb->setChecked(false);
+	hbox->addWidget( ftaCb);
+
+	vbox->addLayout( hbox );
+
+	grid->addLayout( vbox, 0, 0 );
 
 	listView = new KListView( this, "listView" );
 	listView->addColumn( i18n( "Channel" ) );
@@ -100,16 +137,22 @@ KEvents::KEvents( QPtrList<ChannelDesc> *chans, QPtrList<DvbStream> *d, QWidget
 	resetBtn->setGuiItem( KGuiItem(i18n("Refresh"), icon->loadIconSet("reload", KIcon::Small) ) );
 	allBtn->setGuiItem( KGuiItem(i18n("Scheduled"), icon->loadIconSet("date", KIcon::Small) ) );
 	currentNextBtn->setGuiItem( KGuiItem(i18n("Current/Next"), icon->loadIconSet("toggle_log", KIcon::Small) ) );
-	currentChannelEpg->setGuiItem( KGuiItem(i18n("Current Channel"), icon->loadIconSet("date", KIcon::Small) ) );
+	currentChannelEpgBtn->setGuiItem( KGuiItem(i18n("Current Channel"), icon->loadIconSet("date", KIcon::Small) ) );
+	searchBtn->setIconSet( icon->loadIconSet("locationbar_erase", KIcon::Small) );
+
 	new EListViewItem( (QListView*)listView, "Une chaine", "99/99/99  99:99 9999", "99:99 99", "un titre de programme", 0 );
 
 	resize( size );
-	connect( resetBtn			, SIGNAL( clicked() ), this, SLOT( reset() ) );
+	connect( resetBtn			, SIGNAL( pressed() ), this, SLOT( reset() ) );
 	connect( allBtn				, SIGNAL( clicked() ), this, SLOT( setScheduled() ) );
 	connect( currentNextBtn		, SIGNAL( clicked() ), this, SLOT( setCurrentNext() ) );
-	connect( currentChannelEpg	, SIGNAL( clicked() ), this, SLOT( setCurrentChannelEpg() ) );
+	connect( currentChannelEpgBtn, SIGNAL( clicked() ), this, SLOT( setCurrentChannelEpg() ) );
+	connect( searchBtn, 		  SIGNAL( clicked() ), this,	 SLOT(resetSearch()) );
+	connect( searchLineEdit, SIGNAL( returnPressed() ), this, SLOT( epgSearch() ) );
+
 	connect( listView, SIGNAL( mouseButtonClicked(int,QListViewItem*,const QPoint&,int) ),
 		this, SLOT(mouseClickedSlot(int,QListViewItem*,const QPoint&,int)) );
+
 	connect( listView, SIGNAL(doubleClicked(QListViewItem*,const QPoint &,int)),
 		this, SLOT(zap(QListViewItem*,const QPoint &,int)) );
 
@@ -117,6 +160,120 @@ KEvents::KEvents( QPtrList<ChannelDesc> *chans, QPtrList<DvbStream> *d, QWidget
         delete icon;
 }
 
+void KEvents::resetSearch()
+{
+	searchLineEdit->clear();
+}
+
+void KEvents::checkEpgSearch(QString searchword)
+{
+	int i, j, k, m, n, l;
+	EventSource *esrc;
+	EventTsid *et;
+	EventSid *es;
+	EventDesc *desc;
+	EListViewItem *itt=0;
+	ChannelDesc *ch;
+	QString s, begin, duration, title;
+	bool found;
+
+	for( k=0; k<events->getNSource(); k++ ) {
+		if ( !(esrc=events->getNEventSource( k )) )
+			continue;
+		for ( m=0; m<esrc->getNTsid(); m++ ) {
+			if ( !(et=esrc->getNEventTsid( m )) )
+				continue;
+			for ( n=0; n<et->getNSid(); n++ ) {
+				if ( !(es=et->getNEventSid( n )) )
+					continue;
+				for ( j=0; j<es->getNDesc(); j++ ) {
+					if ( !(desc=es->getEventDesc( j )) )
+						continue;
+
+					if ( desc->title.isEmpty() )
+						continue;
+
+					for ( i=0; i<(int)channels->count(); i++ ) {
+						ch = channels->at(i);
+						if ( desc->source==ch->tp.source && desc->sid==ch->sid && desc->tsid==ch->tp.tsid ) {
+							if(tvradioCb->isChecked() && ch->type==2)
+								break;
+
+							if(ftaCb->isChecked() && ch->fta==1)
+								break;
+
+							found=false;
+							if(desc->title.upper().find(searchword.upper())!=-1)
+								found=true;
+
+							if(!desc->subtitle.isEmpty()) {
+								if(desc->subtitle.upper().find(searchword.upper())!=-1)
+									found=true;
+							}
+
+							if(!titleCb->isChecked()) {
+								if(!found) {
+									for ( l=0; l<(int)desc->extEvents.count(); l++ ) {
+										s = *desc->extEvents.at(l);
+										if(!s.isEmpty()) {
+											if(s.upper().find(searchword.upper())!=-1) {
+												found=true;
+												s="";
+												break;
+											}
+										}
+									}
+								}
+								if(!found) {
+									for ( l=0; l<(int)desc->shortEvents.count(); l++ ) {
+										s = desc->shortEvents.at(l)->name;
+										if(!s.isEmpty()) {
+											if(s.upper().find(searchword.upper())!=-1) {
+												found=true;
+												s="";
+												break;
+											}
+										}
+										s = desc->shortEvents.at(l)->text;
+										if(!s.isEmpty()) {
+											if(s.upper().find(searchword.upper())!=-1) {
+												found=true;
+												s="";
+												break;
+											}
+										}
+									}
+								}
+							}
+							if(!found)
+								break;
+
+							begin = KGlobal::locale()->formatDateTime( desc->startDateTime );
+							duration = desc->duration.toString("hh:mm");
+							title = desc->title;
+
+							itt = new EListViewItem( (QListView*)listView, ch->name, begin, duration, title, desc );
+
+							if ( !ch->pix.isNull() )
+								itt->setPixmap( 0, ch->pix );
+						}
+					}
+				}
+			}
+		}
+	}
+}
+
+void KEvents::epgSearch()
+{
+
+	QString text = searchLineEdit->text();
+	if (text.stripWhiteSpace().isEmpty()) return;
+
+	listView->clear();
+	checkEpgSearch(text);
+}
+
 void KEvents::setCurrentChannelEpg()
 {
 	ChannelDesc curchan;
@@ -191,7 +348,7 @@ void KEvents::mouseClickedSlot( int btn, QListViewItem *it, const QPoint &p, int
 				s = s+"</font></b><br>";
 			}
 			s = s+"<br><font color=\"darkred\">";
-			s = s+ei->event->startDateTime.toString()+"<br>";
+			s = s+KGlobal::locale()->formatDateTime( ei->event->startDateTime, false )+"<br>";
 			s = s+ei->event->duration.toString("hh:mm");
 			s = s+"</font><br><br>";
 			for ( i=0; i<(int)ei->event->shortEvents.count(); i++ ) {
@@ -267,65 +424,48 @@ void KEvents::reset()
 
 void KEvents::checkNewEvent()
 {
-	int i, j, k, m, n;
-	DVBevents *events=0;
-	EventSourceList *slist;
-	EventTsidList *tlist;
-	EListViewItem *itt=0;
-	QString s, t, channel, begin, duration, title;
-	bool ret;
+	int i;
+	EventSource *esrc;
+	EventSid *es;
 	EventDesc *desc;
-	QPixmap pix;
-	QValueList<int> sids;
+	EListViewItem *itt=0;
+	ChannelDesc *ch;
+	QString s, t, channel, begin, duration, title;
 
-	for( k=0; k<(int)dvb->count(); k++ ) {
-		events = dvb->at(k)->dvbEvents;
-		events->mutex.lock();
-		for ( m=0; m<(int)events->srcList.count(); m++ ) {
-			slist = events->srcList.at(m);
-			for ( n=0; n<(int)slist->tsidList.count(); n++ ) {
-				tlist = slist->tsidList.at(n);
-				sids.clear();
-				for ( j=0; j<(int)tlist->events.count(); j++ ) {
-					desc = tlist->events.at(j);
-					//if ( mode==1 && desc->tid>0x4f )
-					if ( sids.contains( desc->sid ) )
-						continue;
-					pix = QPixmap();
-					if ( mode==2 ) {
-						if ( !chan )
-							continue;
-						if ( desc->source!=chan->tp.source || desc->sid!=chan->sid || desc->tsid!=chan->tp.tsid )
-							continue;
-						channel = chan->name;
-						pix = chan->pix;
-					}
-					else {
-						ret = true;
-						for ( i=0; i<(int)channels->count(); i++ ) {
-							if ( desc->source==channels->at(i)->tp.source && desc->sid==channels->at(i)->sid && desc->tsid==channels->at(i)->tp.tsid ) {
-								channel = channels->at(i)->name;
-								pix = channels->at(i)->pix;
-								ret = false;
-								sids.append( desc->sid );
-								break;
-							}
-						}
-						if ( ret )
-							continue;
-					}
-					begin = desc->startDateTime.toString( Qt::LocalDate );
-					duration = desc->duration.toString("hh:mm");
-					title = desc->title;
-					if ( title.isEmpty() )
-						continue;
-					itt = new EListViewItem( (QListView*)listView, channel, begin, duration, title, desc );
-					if ( !pix.isNull() )
-						itt->setPixmap( 0, pix );
-				}
-			}
+	if ( mode==2 ) {
+		if ( !chan )
+			return;
+		if ( !(esrc=events->getEventSource( chan->tp.source )) )
+			return;
+		if ( !(es=esrc->getEventSid( chan->tp.tsid, chan->sid )) )
+			return;
+		i = 0;
+		while ( (desc=es->getEventDesc(i)) ) {
+			++i;
+			begin = KGlobal::locale()->formatDateTime( desc->startDateTime );
+			duration = desc->duration.toString("hh:mm");
+			title = desc->title;
+			if ( title.isEmpty() )
+				continue;
+			itt = new EListViewItem( (QListView*)listView, chan->name, begin, duration, title, desc );
+			if ( !chan->pix.isNull() )
+				itt->setPixmap( 0, chan->pix );
+		}
+		return;
+	}
+
+	for ( i=0; i<(int)channels->count(); i++ ) {
+		ch = channels->at(i);
+		if ( (desc=events->getEventDesc( ch->tp.source, ch->tp.tsid, ch->sid, 0 )) ) {
+			begin = KGlobal::locale()->formatDateTime( desc->startDateTime );
+			duration = desc->duration.toString("hh:mm");
+			title = desc->title;
+			if ( title.isEmpty() )
+				continue;
+			itt = new EListViewItem( (QListView*)listView, ch->name, begin, duration, title, desc );
+			if ( !ch->pix.isNull() )
+				itt->setPixmap( 0, ch->pix );
 		}
-		events->mutex.unlock();
 	}
 }
 
