@@ -68,7 +68,7 @@ K_EXPORT_COMPONENT_FACTORY (libxinepart, XinePartFactory)
 
 XinePart::XinePart(QWidget* parentWidget, const char* widgetName, QObject* parent, const char* name, const QStringList& args)
 		: DCOPObject("XinePartIface"),
-		KaffeinePart(parent, name ? name : "XinePart"), m_hrefParam(QString::null), m_autoStart(true), m_imageWindow(true),
+		KaffeinePart(parent, name ? name : "XinePart"),
 		m_current(0), m_xine(NULL), m_pictureSettings(NULL), m_deinterlacerConfigWidget(NULL),
 		m_filterDialog(NULL), m_embeddedContext(NULL)
 {
@@ -77,8 +77,6 @@ XinePart::XinePart(QWidget* parentWidget, const char* widgetName, QObject* paren
 	/*
 	 *   Parsing parameter given by kaffeine (audiodriver, videodriver, verbose)
 	 *   or parameters of <embed>...</embed>
-	 *   Fix for Quicktime movies on www.apple.com:
-	 *   use the given href parameter instead of the URL passed by konqueror
 	 *
 	 *   format: param="value"
 	 */
@@ -109,72 +107,40 @@ XinePart::XinePart(QWidget* parentWidget, const char* widgetName, QObject* paren
 				verbose = true;
 			}
 		}
-
-		if (args[i].left(9).lower()  == "autostart")
-		{
-			if (args[i].section( '"', 1, 1 ).lower() == "false")
-			{
-				kdDebug() << "XinePart: Found parameter autoStart=false, disable autostart" << endl;
-				m_autoStart = false;
-			}
-		}
-		if (args[i].left(4).lower() == "href")
-		{
-			m_hrefParam = args[i].section( '"',1, 1 );
-			kdDebug() << "XinePart: Found href parameter, value: " << m_hrefParam << endl;
-		}
-		if (args[i].left(8).lower() == "controls")
-		{
-			if (args[i].section( '"', 1, 1 ).lower() != "imagewindow")
-			{
-				kdDebug() << "XinePart: Not an ImageWindow object" << endl;
-				m_imageWindow = false;
-			}
-		}
 	}
 
 	// we need an instance
 	setInstance(XinePartFactory::instance());
 
-	// Do not load everything if nothing is to be played
-	if (m_imageWindow)
-	{
-		QString configPath = locateLocal("appdata", "xine-config");
-		//maybe we are inside konqueror or ark
-		if (!configPath.contains("kaffeine"))
-			configPath = locate("data", "kaffeine/xine-config");
-		kdDebug() << "XinePart: Using xine-config file: " << configPath << endl;
+	// be careful - we may be embedded
+	QString configPath = locate("data", "kaffeine/xine-config");
+	QString logoPath = locate("data", "kaffeine/logo");
 
-		QString logoPath = locate("appdata", "logo");
-		if (!logoPath)
-			logoPath = locate("data", "kaffeine/logo");
+	kdDebug() << "XinePart: Using xine-config file: " << configPath << endl;
 
-		m_xine = new KXineWidget(parentWidget, widgetName, configPath, logoPath,
-		                         audioDriver, videoDriver, /* start xine manual*/true, verbose);
-		connect(m_xine, SIGNAL(signalXineFatal(const QString&)), this, SIGNAL(canceled(const QString&)));
-		connect(m_xine, SIGNAL(stopDvb()), this, SIGNAL(stopDvb()));
-		connect(m_xine, SIGNAL(signalDvbOSDHidden()), this, SIGNAL(dvbOSDHide()));
-		m_xine->setFocusPolicy(QWidget::ClickFocus);
-		setWidget(m_xine);
+	m_xine = new KXineWidget(parentWidget, widgetName, configPath, logoPath,
+	                         audioDriver, videoDriver, /* start xine manual*/true, verbose);
+	connect(m_xine, SIGNAL(signalXineFatal(const QString&)), this, SIGNAL(canceled(const QString&)));
+	connect(m_xine, SIGNAL(stopDvb()), this, SIGNAL(stopDvb()));
+	connect(m_xine, SIGNAL(signalDvbOSDHidden()), this, SIGNAL(dvbOSDHide()));
+	m_xine->setFocusPolicy(QWidget::ClickFocus);
+	setWidget(m_xine);
 
-		// set our XML-UI resource file
-		setXMLFile("xine_part.rc");
-		initActions();
-		initConnections();
+	// set our XML-UI resource file
+	setXMLFile("xine_part.rc");
+	initActions();
+	initConnections();
 
-		QTimer::singleShot(0, this, SLOT(slotDisableAllActions()));
-		m_oldPosition = m_xine->mapToGlobal(QPoint(0,0));
-		m_posCheckTimer.start(333);
-	}
+	QTimer::singleShot(0, this, SLOT(slotDisableAllActions()));
+	m_oldPosition = m_xine->mapToGlobal(QPoint(0,0));
+	m_posCheckTimer.start(333);
 }
 
 XinePart::~XinePart()
 {
 	kdDebug() << "XinePart: destructor" << endl;
-	if(m_imageWindow) {
-		kdDebug() << "XinePart destructor: calling saveConfig()" << endl;
-		saveConfig();
-	}
+	kdDebug() << "XinePart destructor: calling saveConfig()" << endl;
+	saveConfig();
 	if (m_embeddedContext)
 		delete m_embeddedContext;
 }
@@ -184,8 +150,7 @@ KAboutData *XinePart::createAboutData()
 	KAboutData* aboutData = new KAboutData( "kaffeine", I18N_NOOP("XinePart"),
 	                                        KAFFEINE_VERSION, I18N_NOOP("A xine based player part for Kaffeine."),
 	                                        KAboutData::License_GPL,
-	                                        "(c) 2003-2004, Jürgen Kofler.", 0, "http://kaffeine.sourceforge.net",
-	                                        "kaffeine-user@lists.sourceforge.net");
+	                                        "(c) 2003-2004, Jürgen Kofler.", 0, "http://kaffeine.sourceforge.net");
 	aboutData->addAuthor("Jürgen Kofler.",0, "kaffeine@gmx.net");
 
 	return aboutData;
@@ -198,10 +163,7 @@ bool XinePart::openURL(const MRL& mrl)
 	//     if (!mrl.kurl().isValid())
 	//         return false;
 
-	if (m_hrefParam.isNull())
-		m_mrl = mrl;
-	else
-		m_mrl = m_hrefParam;
+	m_mrl = mrl;
 	m_playlist.clear();
 	m_current = 0;
 	bool playlist = false;
@@ -294,10 +256,7 @@ bool XinePart::openURL(const MRL& mrl)
 		m_playlist.append(m_mrl);
 	}
 
-	if (m_autoStart)
-	{
-		slotPlay(true);
-	}
+	slotPlay(true);
 
 	return true;
 }
@@ -315,10 +274,6 @@ bool XinePart::closeURL()
 void XinePart::slotPlay(bool forcePlay)
 {
 	kdDebug() << "XinePart::slotPlay()" << endl;
-	if(!m_imageWindow) {
-		kdDebug() << "XinePart::slotPlay() : not initialized, exiting" << endl;
-		return;
-	}
 
 	m_pauseButton->setChecked(false);
 	if (m_xine->isPlaying())
@@ -385,11 +340,6 @@ void XinePart::slotPlay(bool forcePlay)
 
 void XinePart::slotStop()
 {
-	if(!m_imageWindow) {
-		kdDebug() << "XinePart::slotStop() : not initialized, exiting" << endl;
-		return;
-	}
-
 	if (!m_xine->isXineReady())
 		return;
 
@@ -649,6 +599,31 @@ void XinePart::slotSetSubtitle(int channel)
 	m_xine->showOSDMessage(i18n("Subtitle") + ": " + m_subtitles->items()[channel], DEFAULT_OSD_DURATION);
 }
 
+void XinePart::slotAddSubtitle(void)
+{
+	QString subtitleURL = KFileDialog::getOpenURL(m_mrl.kurl().directory(),
+                         i18n("*.smi *.srt *.sub *.txt *.ssa *.asc|Subtitle Files\n*.*|All Files"),
+                         0, i18n("Select Subtitle File")).path();
+
+	if (!(subtitleURL.isEmpty()))
+	{
+		if (!m_playlist[m_current].subtitleFiles().contains(subtitleURL))
+		{
+			m_playlist[m_current].addSubtitleFile(subtitleURL);
+		}
+
+		int subchannel = m_playlist[m_current].subtitleFiles().size() - 1;
+		m_playlist[m_current].setCurrentSubtitle(subchannel);
+		emit signalNewMeta(m_mrl);
+		m_xine->savePosition(m_xine->getPosition()-200);
+		slotPlay(true); //force load of new subtitle
+
+		emit setStatusBarText(i18n("Subtitle") + ": " + m_subtitles->items()[subchannel]);
+		m_xine->showOSDMessage(i18n("Subtitle") + ": " + m_subtitles->items()[subchannel], DEFAULT_OSD_DURATION);
+	}
+
+}
+
 void XinePart::slotSetAudioChannel(int channel)
 {
 	m_xine->slotSetAudioChannel(channel);
@@ -662,7 +637,9 @@ void XinePart::slotSetDVDTitle(const QString& titleStr)
 	uint title = titleStr.toInt(&ok);
 	if (ok && title > 0 && title <= m_xine->getDVDTitleCount())
 	{
-		m_playlist[m_current] = MRL("dvd://" + QString::number(title));
+		KURL url = m_mrl.kurl();
+		url.addPath(QString::number(title));
+		m_playlist[m_current] = MRL(url);
 		slotPlay(true);
 	}
 }
@@ -683,8 +660,10 @@ void XinePart::slotSetDVDAngle(const QString& angleStr)
 	{
 		uint title = m_xine->currentDVDTitleNumber();
 		uint chapter = m_xine->currentDVDChapterNumber();
+		KURL url = m_mrl.kurl();
 
-		m_playlist[m_current] = MRL("dvd://" + QString::number(title) + "." + QString::number(chapter) + "." + QString::number(angle));
+		url.addPath(QString::number(title) + "." + QString::number(chapter) + "." + QString::number(angle));
+		m_playlist[m_current] = MRL(url);
 		slotPlay(true);
 	}
 }
@@ -694,8 +673,10 @@ void XinePart::setDVDChapter(uint chapter)
 	if (chapter > 0 && chapter <= m_xine->getDVDChapterCount())
 	{
 		uint title = m_xine->currentDVDTitleNumber();
+		KURL url = m_mrl.kurl();
 
-		m_playlist[m_current] = MRL("dvd://" + QString::number(title) + "." + QString::number(chapter));
+		url.addPath(QString::number(title) + "." + QString::number(chapter));
+		m_playlist[m_current] = MRL(url);
 		slotPlay(true);
 	}
 }
@@ -798,6 +779,17 @@ void XinePart::slotNewPosition(int pos, const QTime& playtime)
 			m_xine->showOSDMessage(timeMessage, 600, OSD_MESSAGE_LOW_PRIORITY);
 		}
 	}
+	currentPosition = (playtime.hour()*3600)+(playtime.minute()*60)+playtime.second();
+}
+
+QString XinePart::screenShot()
+{
+	QString filename = QDir::homeDirPath()+"/kaffeinedcopshot.jpg";
+	QImage shot = m_xine->getScreenshot();
+	if ( shot.save( filename, "JPEG" ) )
+		return filename;
+	else
+		return "";
 }
 
 void XinePart::slotScreenshot()
@@ -864,24 +856,32 @@ void XinePart::slotDeinterlaceQuality()
 void XinePart::slotSetHue( int i )
 {
 	m_hue = i;
+	if ( i==-1 )
+		return;
 	m_xine->slotSetHue( i );
 }
 
 void XinePart::slotSetSaturation( int i )
 {
 	m_saturation = i;
+	if ( i==-1 )
+		return;
 	m_xine->slotSetSaturation( i );
 }
 
 void XinePart::slotSetContrast( int i )
 {
 	m_contrast = i;
+	if ( i==-1 )
+		return;
 	m_xine->slotSetContrast( i );
 }
 
 void XinePart::slotSetBrightness( int i )
 {
 	m_brightness = i;
+	if ( i==-1 )
+		return;
 	m_xine->slotSetBrightness( i );
 }
 
@@ -1229,6 +1229,7 @@ void XinePart::slotInfo()
 	if (m_xine->hasSaveURL())
 		ts << "<tr><td><b>" << i18n("Save Stream as") << ":</b></td><td> " << m_xine->getSaveURL() << "</td></tr>";
 
+	ts << "<tr><td></td><td></td></tr>"; // added for better layout
 	ts << "</table></qt>";
 	KMessageBox::information(0, info, i18n("Track info") );
 }
@@ -1255,6 +1256,8 @@ void XinePart::slotFinalize()
 		actionCollection()->action("player_play")->plug(m_embeddedContext);
 		actionCollection()->action("player_pause")->plug(m_embeddedContext);
 		actionCollection()->action("player_stop")->plug(m_embeddedContext);
+		actionCollection()->action("volume_increase")->plug(m_embeddedContext);
+		actionCollection()->action("volume_decrease")->plug(m_embeddedContext);
 		actionCollection()->action("audio_mute")->plug(m_embeddedContext);
 		m_embeddedContext->insertSeparator();
 		actionCollection()->action("player_track_info")->plug(m_embeddedContext);
@@ -1340,6 +1343,7 @@ void XinePart::initActions()
 
 	m_audioChannels = new KSelectAction(i18n("Audio Channel"), 0, actionCollection(), "audio_channels");
 	m_audioChannels->setToolTip(i18n("Select audio channel"));
+	m_audioChannels->setComboWidth( 50 );
 	connect(m_audioChannels, SIGNAL(activated(int)), this, SLOT(slotSetAudioChannel(int )));
 	m_audioVisual = new KSelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visualization");
 	connect(m_audioVisual, SIGNAL(activated(const QString&)), m_xine, SLOT(slotSetVisualPlugin(const QString&)));
@@ -1368,9 +1372,11 @@ void XinePart::initActions()
 
 	m_subtitles = new KSelectAction(i18n("Subtitle"), 0, actionCollection(), "player_subtitles");
 	m_subtitles->setToolTip(i18n("Select Subtitle"));
+	m_subtitles->setComboWidth( 50 );
 	connect(m_subtitles, SIGNAL(activated(int)), this, SLOT(slotSetSubtitle(int)));
 	new KAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, this, SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
 	new KAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, this, SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
+	new KAction(i18n("Add subtitle..."), 0, 0, this, SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
 
 	new KAction(i18n("&Menu Toggle"), "view_detailed", Key_D, m_xine, SLOT(slotMenuToggle()), actionCollection(), "dvd_toggle");
 	new KAction(i18n("&Title"), NULL, 0, m_xine, SLOT(slotMenuTitle()), actionCollection(), "dvd_title");
@@ -1503,10 +1509,10 @@ void XinePart::loadConfig()
 	m_broadcastAddress = config->readEntry("Master Address", "localhost");
 
 	config->setGroup( "Video Settings" );
-	slotSetHue(config->readNumEntry( "Hue", 32768));
-	slotSetSaturation(config->readNumEntry( "Saturation", 32768));
-	slotSetContrast(config->readNumEntry( "Contrast", 32768));
-	slotSetBrightness(config->readNumEntry( "Brigthness", 32768));
+	slotSetHue(config->readNumEntry( "Hue", -1));
+	slotSetSaturation(config->readNumEntry( "Saturation", -1));
+	slotSetContrast(config->readNumEntry( "Contrast", -1));
+	slotSetBrightness(config->readNumEntry( "Brigthness", -1));
 
 	m_equalizer->ReadValues(config);
 }
@@ -1568,6 +1574,7 @@ bool XinePart::isPaused()
 	return (m_xine->getSpeed() == KXineWidget::Pause);
 }
 
+#if 0
 void XinePart::audiocdMRLS(MRL::List& mrls, bool& ok, bool& supported, const QString& device)
 {
 	if (!m_xine->isXineReady())
@@ -1718,6 +1725,7 @@ void XinePart::dvdMRLS(MRL::List& mrls, bool& ok, bool& supported, const QString
 	if (mrls.count())
 		ok = true;
 }
+#endif
 
 bool XinePart::hasChapters()
 {
@@ -1765,7 +1773,10 @@ uint XinePart::position() const
 	if (!m_xine->isXineReady())
 		return 0;
 
-	return (int)(m_xine->getPosition() / 655.35);
+	if ( m_xine->isPlaying() )
+		return currentPosition;
+	else
+		return 0;
 }
 
 void XinePart::slotSetVolume(uint vol)
